@@ -128,7 +128,7 @@ class Coinex:
         :param type: 'buy' or 'sell'
         """
         market = market.upper()
-        amount = price * amount
+        amount = amount / price
         amount = round(amount, 8)
 
         if type != 'buy' and type != 'sell':
